import sys
import pygame
from pygame.locals import *

import data
import util
import game
import message
from locals import *

class Intro:

    def __init__(self, screen):
        self.bg = pygame.image.load(data.filepath(IBGCITY)).convert()
        self.tree = pygame.sprite.OrderedUpdates()
        self.tree.add(IntroTree())
        self.tree.add(IntroFoliage())
        self.tree.add(IntroCrown())
        
        self.kinghuman = pygame.sprite.RenderUpdates(IntroKingHuman())
        self.enter_human = False
        
        self.screen = screen

        self.message = pygame.sprite.RenderUpdates()
        self.message.add(message.global_msg)
        self.message.add(message.global_center_msg)
        self.message.add(message.global_human_msg)

        message.global_msg.write('Click to skip intro')

        self.clock = pygame.time.Clock()

        self.timer = 0

    def loop(self):
        self.screen.blit(self.bg, (0, 0))
        pygame.display.update()
        
        self.done = False

        while not self.done:
            for event in pygame.event.get():
                if event.type == QUIT:
                    sys.exit()
                elif event.type == KEYDOWN:
                    if event.key == K_ESCAPE:
                        sys.exit()
                elif event.type == MOUSEBUTTONDOWN:
                    if event.button == 1:
                        self.lets_play()

            self.tree.clear(self.screen, self.bg)
            self.kinghuman.clear(self.screen, self.bg)
            self.message.clear(self.screen, self.bg)
            
            self.tree.update()
            if self.enter_human:
                self.kinghuman.update()
            
            update_rects = []
            update_rects += self.tree.draw(self.screen)
            update_rects += self.kinghuman.draw(self.screen)
            update_rects += self.message.draw(self.screen)
            pygame.display.update(update_rects)

            self.timer += 1
            if self.timer == 100:
                message.global_center_msg.write('Pitiful humans!')
            if self.timer == 200:
                message.global_center_msg.write('I come from another ' +
                                                'dimension to own your ' +
                                                'world!')
            if self.timer == 300:
                message.global_center_msg.write('Hail! King Tree! Mwahaha!')
            if self.timer == 400:
                self.enter_human = True
            if self.timer == 500:
                message.global_center_msg.clear_message()
                message.global_human_msg.write('Frobbershat!')
            if self.timer == 600:
                message.global_human_msg.write('What happen here!')
            if self.timer == 700:
                message.global_human_msg.write('I no know you!')
            if self.timer == 800:
                message.global_human_msg.write('I like shiny plant crown '+
                                               'thingy!')
            if self.timer == 900:
                message.global_human_msg.write('Humans! Get me want crown!')
            if self.timer == 1050:
                self.lets_play()

            self.clock.tick(MAXFPS)

    def lets_play(self):
        message.global_msg.clear_message()
        message.global_human_msg.clear_message()
        message.global_center_msg.clear_message()
        game.Game(self.screen).loop()
        self.done = True
            

class IntroFoliage(pygame.sprite.Sprite):

    def __init__(self):
        pygame.sprite.Sprite.__init__(self)
        
        self.pos = [FOLIAGEPOS[0], FOLIAGEPOS[1] - HEIGHT]

        self.image = (pygame.image.load(data.filepath(IFOLIAGE)).
                      convert_alpha())
        self.rect = self.image.get_rect()
        self.rect.topleft = self.pos

        self.done = False

    def update(self):
        if not self.done:
            self.pos[1] += 10
            if self.pos[1] >= FOLIAGEPOS[1] + 10:
                self.pos[1] = FOLIAGEPOS[1]
                self.done = True

            self.rect.topleft = self.pos


class IntroTree(pygame.sprite.Sprite):

    def __init__(self):
        pygame.sprite.Sprite.__init__(self)

        self.pos = [TREEPOS[0], TREEPOS[1] + HEIGHT]
        
        self.image = pygame.image.load(data.filepath(ITREE)).convert_alpha()
        self.rect = self.image.get_rect()
        self.rect.topleft = self.pos

        self.done = False

    def update(self):
        if not self.done:
            self.pos[1] -= 15
            if self.pos[1] <= TREEPOS[1]:
                self.pos[1] = TREEPOS[1]
                self.done = True

            self.rect.topleft = self.pos


class IntroCrown(pygame.sprite.Sprite):

    def __init__(self):
        pygame.sprite.Sprite.__init__(self)

        self.pos = [CROWNPOS[0], CROWNPOS[1] - HEIGHT * 0.75]

        self.image = pygame.image.load(data.filepath(ICROWN)).convert_alpha()
        self.rect = self.image.get_rect()
        self.rect.center = self.pos

        self.done = False
        
    def update(self):
        if not self.done:
            self.pos[1] += 5
            if self.pos[1] >= CROWNPOS[1]:
                self.pos[1] = CROWNPOS[1]
                self.done = True

            self.rect.center = self.pos


class IntroKingHuman(pygame.sprite.Sprite):

    def __init__(self):
        pygame.sprite.Sprite.__init__(self)

        self.pos = [WIDTH + 30, KINGHUMANPOS[1]]

        self.image = (pygame.image.load(data.filepath(IKINGHUMAN)).
                      convert_alpha())
        self.rect = self.image.get_rect()
        self.rect.center = self.pos

        self.done = False
        
    def update(self):
        if not self.done:
            self.pos[0] -= 5
            if self.pos[0] <= KINGHUMANPOS[0]:
                self.pos[0] = KINGHUMANPOS[0]
                self.done = True

            self.rect.topleft = self.pos
